<?php
defined('BASEPATH') OR exit('No direct script access allowed');
class Currency extends MY_Controller
{
	function __construct(){
		parent::__construct();
		$this->load->model(array('currency_model','common_model'));
	}

	function index(){

		$data['page_title']='Currency List';
		$data['message'] = '';
		$sequence_no=$this->common_model->nextAutoID('fc_currency');
		if( $sequence_no <= 9 ){
			$data['sequence_no']="00".$sequence_no;
		} elseif ($sequence_no >= 10 && $sequence_no <= 99 ) {
			$data['sequence_no']="0".$sequence_no;
		} else {
			$data['sequence_no']=$sequence_no;
		}
		
		$csrf = array(
		        'name' => $this->security->get_csrf_token_name(),
		        'hash' => $this->security->get_csrf_hash()
		);
		$data['csrf']=$csrf;
		$data['user_access']=$this->session->userdata('user_access');
		$this->load->view('currency',$data);
	}

	function insert(){

		$data = array();
		$data['csrf']=$this->security->get_csrf_hash();
		if($this->input->server('REQUEST_METHOD')=='POST' ){

			if( $this->permission->entry_access(2,$this->session->userdata('fcuser_id')) ){
				$result=$this->currency_model->insert();
				if( isset($result['success']) ){

					$data['message']=$this->alert->success($result['success']);
				
				}elseif( isset($result['danger']) ){

					$data['message']=$this->alert->warning($result['danger']);
				}
			}else{
					$data['message']=$this->alert->warning('Permission Denied !!!');
			}

		}else{

			$data['message']=$this->alert->warning('Permission Denied');	
		
		}
		$sequence_no=$this->common_model->nextAutoID('fc_currency');
		if( $sequence_no <= 9 ){
			$data['sequence_no']="00".$sequence_no;
		} elseif ($sequence_no >= 10 && $sequence_no <= 99 ) {
			$data['sequence_no']="0".$sequence_no;
		} else {
			$data['sequence_no']=$sequence_no;
		}
		echo  json_encode($data);
	}

	function getlist(){
		
		$this->load->model("common_model");
		$sql="";
		if( !$this->common_model->verify_user() ){
			$sql.=" AND user_id=".$this->session->userdata('fcuser_id')."  ";
		}

		$results=$this->currency_model->record_list($sql);
		$record['data']=array();
		$sno=0;
		foreach ($results as $result) {

			$curr_account = json_decode($this->common_model->currency_account($result['currency_id']));

			$record['data'][]=array(
					'<span class="badge badge-default">'.$result['currency_code'].'</span>',
					$result['description'],
					number_format($result['buying_rate'],5),
					number_format($result['selling_rate'],5),
					number_format($curr_account->balance_amount,2),
					$curr_account->margin,
					'<a class="update_record btn btn-primary btn-sm caction" href="javascript:void(0)" data-record_id="'.$result['currency_id'].'"><i class="fa fa-edit"></i> ACTION</a>'
			);
		}
		echo json_encode($record);
	}

	function view_record($currency_id){
		if(isset($currency_id)){
			$data['con']=$this->input->get('con');
			$record=$this->currency_model->show($currency_id);
			$data['result']=$record;
			$csrf = array(
			        'name' => $this->security->get_csrf_token_name(),
			        'hash' => $this->security->get_csrf_hash()
			);
			$data['csrf']=$csrf;
			$this->load->view('ajax/getdata.php',$data);
		}
	}

	function update($currency_id){
		if($this->input->server('REQUEST_METHOD')=='POST' ){
			if( $this->permission->modify_access(2,$this->session->userdata('fcuser_id')) ){
				$result=$this->currency_model->update($currency_id);
				if( isset($result['success']) ){
					$message_status=$this->alert->success($result['success']);
				}elseif( isset($result['danger']) ){
					$message_status=$this->alert->danger($result['danger']);
				}
			}else{
				$message_status=$this->alert->danger('Permission Denied !!!');
			}
			echo $message_status;
		}
	}

	function delete($currency_id){
		if($this->input->server('REQUEST_METHOD')=='GET' ){
			if( $this->permission->modify_access(2,$this->session->userdata('fcuser_id')) ){
				$result=$this->currency_model->delete($currency_id);
				if( isset($result['success']) ){
					$message_status=$this->alert->success($result['success']);
				}elseif( isset($result['danger']) ){
					$message_status=$this->alert->danger($result['danger']);
				}
			}else{
					$message_status=$this->alert->danger('Permission Denied !!!');
			}
			echo $message_status;
		}
	}

	function currency_info($currency_id){
		$record = $this->currency_model->show($currency_id);
		$data = array(
					'description'	=>	$record['description'],
					'rate_unit'		=>	number_format($record['rate_unit']),
					'buying_rate'	=>	number_format($record['buying_rate'],5),
					'selling_rate'	=>	number_format($record['selling_rate'],5),
					'margin'		=>	number_format($record['margin'],5),
					'opstock'		=>	number_format($record['opstock'],2),
					'oprate'		=>	number_format($record['oprate'],10),
					'manual_stock'	=>	number_format($record['manual_stock'],2),
					'rate'			=>	number_format($record['rate'],10),
					'min_denom'		=>	number_format($record['min_denom'],2)
				);
		echo json_encode($data);
	}

	public function daily_update_get()
	{
		$data['con'] = 1;
		$results=$this->currency_model->record_list();
		foreach ($results as $result) {
			$stock = $result['stock_credit']-$result['stock_debit'];
			$data['results'][]=array(
				'currency_code' =>	'<span class="badge badge-default">'.$result['currency_code'].'</span>',
				'buying_rate'	=>	 $result['buying_rate'],
				'selling_rate'	=>	 $result['selling_rate'],
				'currency_id'	=>   $result['currency_id'],
				'stock'			=>   $stock,
				'avg_rate'		=>   $result['currency_avg_rate']
			);
		}
		$this->load->view('ajax/currency', $data);
	}

	public function daily_update_info()
	{
		$data['con'] = 2;
		$sdate = date('Y-m-d', strtotime(str_replace("/","-",$this->input->get('fdate'))));
		$data['sdate'] = $this->input->get('fdate');
		$results=$this->db->query(" SELECT * FROM `fc_currency_sell_buy` A LEFT JOIN fc_currency_sell_buy_list B ON A.id=B.id WHERE sdate='$sdate' ");
		$data['results'] = [];
		foreach ($results->result_array() as $result) {
			
			$currency_arr = $this->currency_model->show($result['currency_id']);
			$currency_name = $currency_arr['currency_code'];

			$data['results'][]=array(
				'currency_code' =>	'<span class="badge badge-default">'.$currency_name.'</span>',
				'buying_rate'	=>	 $result['buying_rate'],
				'selling_rate'	=>	 $result['selling_rate'],
				'currency_id'	=>   $result['currency_id'],
				'stock'			=>   $result['stock'],
				'avg_rate'		=>   $result['avg_rate']
			);
		}
		$this->load->view('ajax/currency', $data);
	}

	public function daily_update_post()
	{
		if( $this->input->server('REQUEST_METHOD') == 'POST' ){
			extract($_REQUEST);
			$error = 0;
			$this->db->trans_begin();
			$sdate = date('Y-m-d', strtotime(str_replace("/","-",$this->input->post('daily_currency_update_date'))));

			$row_check = $this->db->get_where('fc_currency_sell_buy', ['sdate' => $sdate]);
			$eod_check = $this->db->query(" SELECT settlement_id FROM `fc_settlement` WHERE closing_date>='$sdate'  ");
			if($row_check->num_rows() > 0 && $eod_check->num_rows() > 0){ 
				$data = ['status' => 'Warning', 'message' => 'Already updated'];
				++$error;
			}
		if($error == 0){
			// DELETE IF RECORD ALREADY EXIST
			$this->db->query(" DELETE A, B FROM fc_currency_sell_buy A INNER JOIN  fc_currency_sell_buy_list B ON A.id=B.id WHERE sdate='".$sdate."' ");
			$query = $this->db->query(" INSERT INTO fc_currency_sell_buy(sdate)VALUES('".$sdate."') ");
			$sid = $this->db->insert_id();
			if($query){
				for ($i=0; $i < count($currencies); $i++) { 
					
					$this->db->query("UPDATE fc_currency SET selling_rate='".$selling_rate[$i]."', 
					buying_rate='".$buying_rate[$i]."' WHERE currency_id='".$currencies[$i]."' ");

					$this->db->query(" INSERT INTO fc_currency_sell_buy_list(id,`currency_id`, 
						`selling_rate`,`buying_rate`, `stock`, `avg_rate`)VALUES($sid,
						'".$currencies[$i]."',
						'".$selling_rate[$i]."',
						'".$buying_rate[$i]."',
						'".$stock[$i]."',
						'".$avg[$i]."'
					) ");
				}

				if ($this->db->trans_status() === FALSE)
				{
				    $this->db->trans_rollback();
				    $data = ['status' => 'Warning', 'message' => 'Something went wrong'];
				}
				else
				{
				    $this->db->trans_commit();
				    $data = ['status' => 'Success', 'message' => 'Data updated successfully'];
				}
			}
		}
		
			echo json_encode($data);
		}
	}

}
?>