<?php
defined('BASEPATH') OR exit('No direct script access allowed');
class User extends MY_Controller
{
	function __construct(){
		parent::__construct();
		$this->load->model(array('user_model','common_model'));
	}

	function index(){
		$data['page_title']='User Panel';
		$data['message'] = '';
		$csrf = array(
		        'name' => $this->security->get_csrf_token_name(),
		        'hash' => $this->security->get_csrf_hash()
		);
		$data['csrf']=$csrf;
		/* form submission*/
		if($this->input->server('REQUEST_METHOD')=='POST' ){

			if( $this->permission->entry_access(1,$this->session->userdata('fcuser_id')) ){
				$result=$this->user_model->insert();

				if( isset($result['success']) ){

					$data['message']=$this->alert->success($result['success']);
				
				}elseif( isset($result['danger']) ){

					$data['message']=$this->alert->warning($result['danger']);
				}
			}else{
					$data['message']=$this->alert->warning('Permission Denied !!!');
			}
		}

		$data['access']=$this->user_model->access();
		$data['client_groups']=$this->user_model->client_groups();
		$data['currencies']=$this->user_model->currencies();
		$data['user_access']=$this->session->userdata('user_access');
		$this->load->view('user',$data);
	}


	function getlist(){
		$results=$this->user_model->record_list();
		$record['data']=array();
		$sno=0;

		foreach ($results as $result) {
			$status = ($result['status']==1)?'<a href="javascript:;" class="badge badge-success user_status" data-rid="'.$result['user_id'].'">Active</a>':'<a href="javascript:;" class="badge badge-danger user_status" data-rid="'.$result['user_id'].'">In-Active</a>';
			$record['data'][]=array(
					$result['name'],
					$result['user'],
					$status,
					'<a class="update_record btn btn-primary btn-sm caction" href="javascript:void(0)" data-record_id="'.$result['user_id'].'"><i class="fa fa-edit"></i> ACTION</a>'
			);
		}
		echo json_encode($record);
	}

	function view_record($user_id){
		if(isset($user_id)){
			$data['con']=$this->input->get('con');
			$record=$this->user_model->show($user_id);
			$data['result']=$record;
			$csrf = array(
			        'name' => $this->security->get_csrf_token_name(),
			        'hash' => $this->security->get_csrf_hash()
			);
			$data['csrf']=$csrf;
			$add_access=array();
			foreach ($this->user_model->access() as $key => $value) {
				$checked =FALSE;
				if($this->user_model->user_access($user_id,$value['access_id'],1)){
					$checked = TRUE;
				}
				
				$add_access[]=array(
					'title'		=> $value['title'],
					'access_id'	=> $value['access_id'],
					'checked'	=> $checked
				);
			}
			$data['add_access'] = $add_access;

			/* modification access */
			$modify_access=array();
			foreach ($this->user_model->access() as $key => $value) {
				$checked =FALSE;
				if($this->user_model->user_access($user_id,$value['access_id'],2)){
					$checked = TRUE;
				}
				
				$modify_access[]=array(
					'title'		=> $value['title'],
					'access_id'	=> $value['access_id'],
					'checked'	=> $checked
				);
			}
			$data['modify_access'] = $modify_access;
			
			/* client group */
			$client_groups=array();
			foreach ($this->user_model->client_groups() as $key => $value) {
				$checked =FALSE;
				if($this->user_model->client_currency($user_id,$value['client_id'],0)){
					$checked = TRUE;
				}
				
				$client_groups[]=array(
					'client_id'		=> $value['client_id'],
					'client_code'	=> $value['client_code'],
					'checked'	=> $checked
				);
			}
			$data['client_groups']=$client_groups;

			/*currecny*/
			$currencies=array();
			foreach ($this->user_model->currencies() as $key => $value) {
				$checked =FALSE;
				if($this->user_model->client_currency($user_id,$value['currency_id'],1)){
					$checked = TRUE;
				}
				
				$currencies[]=array(
					'currency_id'	=> $value['currency_id'],
					'currency_code'	=> $value['currency_code'],
					'checked'	=> $checked
				);
			}
			$data['currencies']=$currencies;

			$this->load->view('ajax/getdata.php',$data);
		}
	}

	function update($user_id){
		if($this->input->server('REQUEST_METHOD')=='POST' ){
			if( $this->permission->modify_access(1,$this->session->userdata('fcuser_id')) ){
				$result=$this->user_model->update($user_id);
				if( isset($result['success']) ){
					$message_status=$this->alert->success($result['success']);
				}elseif( isset($result['danger']) ){
					$message_status=$this->alert->danger($result['danger']);
				}
			}else{
					$message_status=$this->alert->danger('Permission Denied !!!');
			}
			$this->session->set_flashdata('message', $message_status);
			redirect('user','refresh');
		}
	}

	function delete($user_id){
		if($this->input->server('REQUEST_METHOD')=='GET' ){
			if( $this->permission->modify_access(1,$this->session->userdata('fcuser_id')) ){
				$result=$this->user_model->delete($user_id);
				if( isset($result['success']) ){
					$message_status=$this->alert->success($result['success']);
				}elseif( isset($result['danger']) ){
					$message_status=$this->alert->danger($result['warning']);
				}
			}else{
					$message_status=$this->alert->danger('Permission Denied !!!');
			}
			echo $message_status;
		}
	}
	
	function user_status(int $id)
	{
	    $query = $this->db->query(" UPDATE `fc_users` SET status=IF(status=1,0,1) WHERE user_id='$id' ");
	    if($query)
	    {
	        $record=$this->user_model->show($id);
	        $data = ['status' => $record['status'], 'message' => 'User status updated successfully'];
	    }
	    else
	    {
	        $data = ['status' => '0', 'message' => 'Bad request'];
	    }
	    echo json_encode($data);
	}

}
?>