<?php
if (!defined('BASEPATH')) exit('No direct script access allowed');

class Employee extends MY_Controller {

    function __construct() {
        parent::__construct();
        $this->load->model('payroll/employee_model');
        if( !$this->permission->entry_access(8,$this->session->userdata('fcuser_id')) ){
        	redirect('dashboard'); die();
        }
    }

    /*
		Display listing
    */
    public function index() 
    {
       	$data['page_title']		=	'Employee List';
		$data['user_access']	=	$this->session->userdata('user_access');
		$data['ftype'] = 0;
		if(!empty($this->input->get('type'))){
			$data['ftype'] = $this->input->get('type');
		}
		$this->load->view('payroll/view-employee',$data);
    }

    /*
		Show form to create new record 
    */
	public function create()
	{
		$data['page_title']		=	'Add New Employee';
		$data['user_access']	=	$this->session->userdata('user_access');
		$data['deductions'] 	=	$this->employee_model->deduction_list();
		$data['contributions']	=	$this->employee_model->econtribution_list();
		$this->load->model('client_model');
		$data['clients']		=	$this->client_model->clients();
		$this->load->view('payroll/new-employee',$data);
	}

	/*
		Store newly created record
	*/
	public function store()
	{
		$data 				= 	array();
		$data['success']	=	"";
		$data['errors']		=	"";
		$message ="";
		if($this->input->server('REQUEST_METHOD')=='POST' ){
			if( $this->permission->entry_access(8,$this->session->userdata('fcuser_id')) ){
				if( $this->employee_model->insert($this->input->post()) ){
					$message = 'New Employee Details Added Successfully';
				}else{
					$message = 'Please try again';
				}
			}else{
				$message = 'Permission Denied';
			}			
		}else{
			$message = 'Permission Denied';
		}
		$this->session->set_flashdata('data', $message);
		redirect('payroll/employee/create','refresh');
	}

	/*
		update specific record
	*/
	public function edit($id)
	{
		$data['page_title']		=	'Edit Employee Info';
		$data['user_access']	=	$this->session->userdata('user_access');
		$data['deductions'] 	=	$this->employee_model->deduction_list();
		$data['contributions']	=	$this->employee_model->econtribution_list();
		$this->load->model('client_model');
		$data['clients']		=	$this->client_model->clients();

		$data['success']	=	array();
		$data['errors']		=	array();
		if($this->input->server('REQUEST_METHOD')=='POST' ){
			if( $this->permission->modify_access(8,$this->session->userdata('fcuser_id')) ){
				if( $this->employee_model->update($this->input->post(),$id) ){
					$data['success'] = 'Employee Info Successfully';
				}else{
					$data['errors']['warning'] = 'Please try again';
				}
			}else{
				$data['errors']['warning'] = 'Permission Denied';
			}	
			$this->session->set_flashdata('data', $data);	
			redirect('payroll/employee/create','refresh');	
		}
		
		
		$where = array();
		$this->load->model("common_model");
		if( !$this->common_model->verify_user() ){
			$where['user_id'] = $this->session->userdata('fcuser_id');
		}
		$where['employee_id']			=	$id;
		$employee_info 					=	$this->employee_model->get($where);
		$data['employee_info']			=	$employee_info;
		$data['payroll_info']			=	$this->employee_model->payroll_info($id);
		$data['deduction_details']		=	$this->employee_model->deduction_details($id);
		$data['econtribution_details']	=	$this->employee_model->econtribution_details($id);

		$credit_account = $this->client_model->show($employee_info->credit_id);
		$debit_account = $this->client_model->show($employee_info->debit_id);
		$data['credit_account'] = $credit_account['client_code'];
		$data['debit_account']  = $debit_account['client_code'];

		$adcredit_account = $this->client_model->show($employee_info->advance_credit_id);
		$addebit_account = $this->client_model->show($employee_info->advance_debit_id);
		$data['adcredit_account'] = $adcredit_account['client_code'];
		$data['addebit_account']  = $addebit_account['client_code'];

		$lncredit_account = $this->client_model->show($employee_info->loan_credit_id);
		$lndebit_account = $this->client_model->show($employee_info->loan_debit_id);
		$data['lncredit_account'] = $lncredit_account['client_code'];
		$data['lndebit_account']  = $lndebit_account['client_code'];

		$sadcredit_account = $this->client_model->show($employee_info->sadv_credit_id);
		$saddebit_account = $this->client_model->show($employee_info->sadv_debit_id);
		$data['sadcredit_account'] = $sadcredit_account['client_code'];
		$data['saddebit_account']  = $saddebit_account['client_code'];

		$slncredit_account = $this->client_model->show($employee_info->sln_credit_id);
		$slndebit_account = $this->client_model->show($employee_info->sln_debit_id);
		$data['slncredit_account'] = $slncredit_account['client_code'];
		$data['slndebit_account']  = $slndebit_account['client_code'];

		$travel_credit_account = $this->client_model->show($employee_info->travel_credit_id);
		$travel_debit_account = $this->client_model->show($employee_info->travel_debit_id);
		$data['travel_credit_acc'] = $travel_credit_account['client_code'];
		$data['travel_debit_acc']  = $travel_debit_account['client_code'];

		$bonus_credit_account = $this->client_model->show($employee_info->bonus_credit_id);
		$bonus_debit_account = $this->client_model->show($employee_info->bonus_debit_id);
		$data['bonus_credit_acc'] = $bonus_credit_account['client_code'];
		$data['bonus_debit_acc']  = $bonus_debit_account['client_code'];



		$this->load->view('payroll/edit-employee',$data);
	}

	/*
		Remove particular record
	*/
	public function destroy($id)
	{
		if($this->input->server('REQUEST_METHOD')=='GET' ){
			if( $this->permission->modify_access(8,$this->session->userdata('fcuser_id')) ){
				$result=$this->employee_model->delete($id);
				if( isset($result['success']) ){
					$message_status=$this->alert->success($result['success']);
				}elseif( isset($result['danger']) ){
					$message_status=$this->alert->danger($result['danger']);
				}
			}else{
					$message_status=$this->alert->danger('Permission Denied !!!');
			}
			echo $message_status;
		}
	}

	function ajax(){
		
		$this->load->model("common_model");
		$sql = "";
		if( !$this->common_model->verify_user() ){
			//$sql .= " AND user_id='".$this->session->userdata('fcuser_id')."' ";
			//$sql['user_id'] = $this->session->userdata('fcuser_id');
		}

		if(!empty($this->input->get('ftype'))){
			if($this->input->get('ftype') == 1){
				$sql .= " AND employee_id IN ( SELECT employee_id FROM `fc_loan_account` WHERE credit_amount > debit_amount ) ";
			}
			if($this->input->get('ftype') == 2){
				$sql .= " AND employee_id IN ( SELECT employee_id FROM `fc_salary_advance_account` WHERE credit_amount > debit_amount ) ";
			}
		}

		$query = $this->db->query(" SELECT * FROM `fc_employee` WHERE 1 ".$sql." 
					ORDER BY employee_id DESC ");
		$results = $query->result();
		//$results=$this->employee_model->get($sql);

		$record['data']=array();
		$sno=0;
		$this->load->model('client_model');
		if(!empty($results)){
			$this->load->model(array('payroll/advance_model','payroll/loan_model'));
		foreach ($results as $result) {
			
			$credit_account = $this->client_model->show($result->credit_id);
			$debit_account = $this->client_model->show($result->debit_id);
			
			$advance_account = $this->advance_model->advance_account($result->employee_id);
			$loan_account = $this->loan_model->advance_account($result->employee_id);

			$record['data'][]=array(
					++$sno,
					'<span class="badge badge-default">'.$result->employee_code.'</span>',
					$result->employee_name,
					'<span class="badge badge-info">'.number_format($advance_account['balance_amount'],2).'</span>',
					'<span class="badge badge-warning">'.number_format($loan_account['balance_amount'],2).'</span>',
					//$credit_account['client_code'].'-'.$credit_account['name'],
					//$debit_account['client_code'].'-'.$debit_account['name'],
					'<a class="update_record btn btn-primary btn-sm caction" href="javascript:void(0)" data-record_id="'.$result->employee_id.'"><i class="fa fa-edit"></i> Action</a>'
			);
		}
		}
		echo json_encode($record);
	}

}
