<?php
if (!defined('BASEPATH')) exit('No direct script access allowed');

class Employee_model extends CI_Model {

    /**
     * @name string TABLE_NAME Holds the name of the table in use by this model
     */
    const TABLE_NAME = 'fc_employee';

    /**
     * @name string PRI_INDEX Holds the name of the tables' primary index used in this model
     */
    const PRI_INDEX = 'employee_id';

    /**
     * Retrieves record(s) from the database
     *
     * @param mixed $where Optional. Retrieves only the records matching given criteria, or all records if not given.
     *                      If associative array is given, it should fit field_name=>value pattern.
     *                      If string, value will be used to match against PRI_INDEX
     * @return mixed Single record if ID is given, or array of results
     */
    public function get($where = NULL) {
        $this->db->select('*');
        $this->db->from(self::TABLE_NAME);
        if ($where !== NULL) {
            if (is_array($where)) {
                foreach ($where as $field=>$value) {
                    $this->db->where($field, $value);
                }
            } else {
                $this->db->where(self::PRI_INDEX, $where);
            }
        }
        $this->db->order_by("employee_id", "desc");
        $result = $this->db->get()->result();
        if ($result) {
            if ($where !== NULL) {
                return array_shift($result);
            } else {
                return $result;
            }
        } else {
            return false;
        }
    }

    function payroll_info($id){
    	$this->db->select('*');
        $this->db->from('fc_payroll_information');
        $this->db->where('employee_id', $id);
        $result = $this->db->get()->result();
        return array_shift($result);
    }

    function deduction_details($id){
    	$this->db->select('*');
        $this->db->from('fc_deduction_details');
        $this->db->where('employee_id', $id);
        $result = $this->db->get()->result();
        return $result;
    }

    function econtribution_details($id){
    	$this->db->select('*');
        $this->db->from('fc_econtribution_details');
        $this->db->where('employee_id', $id);
        $result = $this->db->get()->result();
        return $result;
    }

    /**
     * Inserts new data into database
     *
     * @param Array $data Associative array with field_name=>value pattern to be inserted into database
     * @return mixed Inserted row ID, or false if error occured
     */
    public function insert(Array $data) {
    	extract($_REQUEST);
    	$record['employee_code']	=	$data['employee_code'];
    	$record['employee_name']	=	$data['employee_name'];
    	$record['gender']			=	$data['gender'];
    	$record['mobile']			=	$data['mobile'];
    	$record['email']			=	$data['email'];
    	$record['credit_id']		=	$data['credit_id'];
    	$record['debit_id']			=	$data['debit_id'];
        $record['advance_credit_id'] =  $data['advance_credit_id'];
        $record['advance_debit_id']  =  $data['advance_debit_id'];
        $record['loan_credit_id']    =  $data['loan_credit_id'];
        $record['loan_debit_id']     =  $data['loan_debit_id'];
        $record['sadv_credit_id']    =  $data['sadv_credit_id'];
        $record['sadv_debit_id']     =  $data['sadv_debit_id'];
        $record['sln_credit_id']     =  $data['sln_credit_id'];
        $record['sln_debit_id']      =  $data['sln_debit_id'];
        $record['travel_credit_id']  =  $data['travel_credit_id'];
        $record['travel_debit_id']   =  $data['travel_debit_id'];
        $record['bonus_credit_id']   =  $data['bonus_credit_id'];
        $record['bonus_debit_id']    =  $data['bonus_debit_id'];
    	$record['created_at']		=	date('Y-m-d H:i:s');
    	$record['user_id']			=	$this->session->userdata('fcuser_id');
    	$record['status']			=	1;

        if ($this->db->insert(self::TABLE_NAME, $record)) {
            $employee_id = $this->db->insert_id();
           	$this->db->query(" INSERT INTO fc_payroll_information set employee_id='$employee_id', 
           		basic='".$data['basic']."', allowance='".$data['allowance']."', hra='".$data['hra']."', 
           		special_allowance='".$data['special_allowance']."', 
           		total_gross='".$data['total_gross']."' "); 
           	$payroll_information_id=$this->db->insert_id();
           	for( $i=0; $i<count($data['deduction']); $i++ ){
           		$checkbox = 0;
           		if(!empty($data['format_type'][$i+1]) && ($data['format_type'][$i+1] == $data['deduction_id'][$i])){
           			$checkbox = 1;
           		}
		       $this->db->query(" INSERT INTO fc_deduction_details set employee_id='$employee_id',
		        `type`='".$checkbox."',  deduction_id='".$data['deduction_id'][$i]."', 
		        title='".$data['deduction'][$i]."', deduction_from='".$data['deduction_from'][$i]."', 
		        percentage='".$data['percentage'][$i]."', srt='".$data['srt'][$i]."', 
		        payroll_information_id='$payroll_information_id' ");
		    }

		    for( $i=0; $i<count($data['ec']); $i++ ){
		    	$checkbox = 0;
           		if(!empty($data['ecformat_type'][$i+1]) && ($data['ecformat_type'][$i+1] == $data['contribution_id'][$i])){
           			$checkbox = 1;
           		}
		        $this->db->query(" INSERT INTO fc_econtribution_details set employee_id='$employee_id',
		        `type`='".$checkbox."', contribution_id='".$data['contribution_id'][$i]."', 
		        title='".$data['ec'][$i]."', deduction_from='".$data['ec_from'][$i]."', 
		        percentage='".$data['ec_percentage'][$i]."', srt='".$data['esrt'][$i]."',
		        payroll_information_id='$payroll_information_id' ");
		    }
		    
		    $this->db->query(" UPDATE `fc_employee` SET payroll_information_id='$payroll_information_id' WHERE employee_id='$employee_id' ");

		    return true;
        } else {
            return false;
        }
    }

    /**
     * Updates selected record in the database
     *
     * @param Array $data Associative array field_name=>value to be updated
     * @param Array $where Optional. Associative array field_name=>value, for where condition. If specified, $id is not used
     * @return int Number of affected rows by the update query
     */
    public function update(Array $data, $where) {
        if (!is_array($where)) {
            $where = array(self::PRI_INDEX => $where);
        }
        $record['employee_code']	=	$data['employee_code'];
    	$record['employee_name']	=	$data['employee_name'];
    	$record['gender']			=	$data['gender'];
    	$record['mobile']			=	$data['mobile'];
    	$record['email']			=	$data['email'];
    	$record['credit_id']		=	$data['credit_id'];
    	$record['debit_id']			=	$data['debit_id'];
        $record['advance_credit_id'] =  $data['advance_credit_id'];
        $record['advance_debit_id']  =  $data['advance_debit_id'];
        $record['loan_credit_id']    =  $data['loan_credit_id'];
        $record['loan_debit_id']     =  $data['loan_debit_id'];
        $record['sadv_credit_id']    =  $data['sadv_credit_id'];
        $record['sadv_debit_id']     =  $data['sadv_debit_id'];
        $record['sln_credit_id']     =  $data['sln_credit_id'];
        $record['sln_debit_id']      =  $data['sln_debit_id'];
        $record['travel_credit_id']  =  $data['travel_credit_id'];
        $record['travel_debit_id']   =  $data['travel_debit_id'];
        $record['bonus_credit_id']   =  $data['bonus_credit_id'];
        $record['bonus_debit_id']    =  $data['bonus_debit_id'];
    	$record['created_at']		 =	date('Y-m-d H:i:s');
    	$record['user_id']			 =	$this->session->userdata('fcuser_id');
    	$record['status']			 =	1;
        $this->db->update(self::TABLE_NAME, $record, $where);
        if($this->db->affected_rows()){
        	
        	$payroll_information_id = $data['payroll_information_id'];
        	$employee_id = $data['employee_id'];

        	$this->db->query(" UPDATE fc_payroll_information SET basic='".$data['basic']."', 
        		allowance='".$data['allowance']."', hra='".$data['hra']."', 
           		special_allowance='".$data['special_allowance']."', total_gross='".$data['total_gross']."' 
           		WHERE payroll_information_id='".$payroll_information_id."' "); 
        
        /*Deduction details*/	
        	$this->db->query(" DELETE FROM `fc_deduction_details` where payroll_information_id='$payroll_information_id' ");

        	for( $i=0; $i<count($data['deduction']); $i++ ){
           		$checkbox = 0;
           		if(!empty($data['format_type'][$i+1]) && ($data['format_type'][$i+1] == $data['deduction_id'][$i])){
           			$checkbox = 1;
           		}
		       $this->db->query(" INSERT INTO fc_deduction_details set employee_id='$employee_id',
		        `type`='".$checkbox."',  deduction_id='".$data['deduction_id'][$i]."', 
		        title='".$data['deduction'][$i]."', deduction_from='".$data['deduction_from'][$i]."', 
		        percentage='".$data['percentage'][$i]."', srt='".$data['srt'][$i]."', 
		        payroll_information_id='$payroll_information_id' ");
		    }
		/*END Deduction details*/

		/*Contribution details*/
			$this->db->query(" DELETE FROM `fc_econtribution_details` where payroll_information_id='$payroll_information_id' ");

			for( $i=0; $i<count($data['ec']); $i++ ){
		    	$checkbox = 0;
           		if(!empty($data['ecformat_type'][$i+1]) && ($data['ecformat_type'][$i+1] == $data['contribution_id'][$i])){
           			$checkbox = 1;
           		}

		        $this->db->query(" INSERT INTO fc_econtribution_details set employee_id='$employee_id',
		        `type`='".$checkbox."', contribution_id='".$data['contribution_id'][$i]."', 
		        title='".$data['ec'][$i]."', deduction_from='".$data['ec_from'][$i]."', 
		        percentage='".$data['ec_percentage'][$i]."', srt='".$data['esrt'][$i]."',
		        payroll_information_id='$payroll_information_id' ");
		    }
		/*END Contribution details*/

        	return true;
        }else{
        	return false;
        }
    }

    /**
     * Deletes specified record from the database
     *
     * @param Array $where Optional. Associative array field_name=>value, for where condition. If specified, $id is not used
     * @return int Number of rows affected by the delete query
     */
    function delete($id){
		$query=$this->db->query(" DELETE FROM `fc_employee` where employee_id='$id' ");
		if($this->db->affected_rows()){

			$this->db->query(" DELETE FROM `fc_payroll_information` where employee_id='$id' ");
			$this->db->query(" DELETE FROM `fc_deduction_details` where employee_id='$id' ");
			$this->db->query(" DELETE FROM `fc_econtribution_details` where employee_id='$id' ");

			$result['success']='Record removed successfully !!!';
		}else{
			$result['danger']='Sorry... Unable to remove this currency !!!';
		}
		return $result;
	}

    function deduction_list(){
    	$query = $this->db->query(" SELECT * FROM `fc_deduction_list` ORDER BY srt ");
    	return $query->result_array();
    }

    function econtribution_list(){
    	$query = $this->db->query(" SELECT * FROM `fc_econtribution_list` ORDER BY srt ");
    	return $query->result_array();
    }
}
